@@ -16,7 +16,5 @@ except _metadata.PackageNotFoundError:  # pragma: no-cover
     # If the package is not installed such that it has distribution metadata
     # fallback to loading the version from the pyproject.toml file.
     __version__ = _toml.loads(
-        _pathlib.Path(__file__)
-        .parent.parent.joinpath('pyproject.toml')
-        .read_text()
-    )['tool']['poetry']['version']
+        _pathlib.Path(__file__).parent.parent.joinpath("pyproject.toml").read_text()
+    )["tool"]["poetry"]["version"]
